﻿using System.Text;
using System.Windows;
using Microsoft.Maps.Core;
using Microsoft.Maps.MapControl;
using MsdnMag.ObaLib;

namespace MsdnMag.ObaApp
{
	public class BusStopEntity : Entity
	{
		private readonly DependencyProperty NamePropertyKey =
			Entity.RetrieveProperty("Name", typeof(string));

		private BusStop _busStop;

		internal BusStop BusStop
		{
			get { return _busStop; }
		}

		// short name of the bus stop
		public string Name
		{
			get { return _busStop.Name; }
		}

		// Id of the bus stop
		public string StopId
		{
			get { return _busStop.Id; }
		}

		public string BusRoutesAsString
		{
			get
			{
				if (_busStop.BusRoutes != null && _busStop.BusRoutes.Count > 0)
				{
					StringBuilder sb = new StringBuilder();
					foreach (var route in _busStop.BusRoutes)
					{
						if (sb.Length > 0)
						{
							sb.Append(", ");
						}
						sb.Append(route.ShortName);
					}
					return sb.ToString();
				}
				else
				{
					return "(none)";
				}
			}
		}

		public BusStopEntity(BusStop busStop, PushpinFactoryContract pushpinFactory)
		{
			_busStop = busStop;

			// set the location of this Entity
			Location location = new Location(busStop.Latitude, busStop.Longitude);
			this.Primitive = pushpinFactory.CreateStandardPushpin(location, "B");

			// set the name of this Entity
			this.SetValue(NamePropertyKey, busStop.Name);
		}
	}
}