﻿
using System;
using System.Collections.Generic;

namespace MsdnMag.ObaLib
{
	/// <summary>
	/// Contains data to represent a bus route.
	/// </summary>
	public class BusRoute : IEquatable<BusRoute>
	{
		/// <summary>
		/// Gets the bus route's Id.
		/// </summary>
		/// <value>The id.</value>
		public string Id { get; private set; }

		/// <summary>
		/// Gets the bus route's short name.
		/// </summary>
		/// <value>The short name.</value>
		public string ShortName { get; private set; }

		/// <summary>
		/// Gets the bus route's long name.
		/// </summary>
		/// <value>The long name.</value>
		public string LongName { get; private set; }

		/// <summary>
		/// Gets the bus route's description.
		/// </summary>
		/// <value>The description.</value>
		public string Description { get; private set; }

		/// <summary>
		/// Gets the collection of bus stops belonging to this route.
		/// </summary>
		public ICollection<BusStop> Stops;

		/// <summary>
		/// Initializes a new instance of the <see cref="BusRoute"/> class.
		/// </summary>
		/// <param name="id">The id.</param>
		/// <param name="shortName">The short name.</param>
		/// <param name="longName">The long name.</param>
		/// <param name="description">The description.</param>
		/// <param name="stops">The stops.</param>
		public BusRoute(
			string id, 
			string shortName, 
			string longName,
			string description,
			ICollection<BusStop> stops)
		{
			this.Id = id;
			this.ShortName = shortName;
			this.LongName = longName;
			this.Description = description;
			this.Stops = stops;
		}

		/// <summary>
		/// Equalses the specified other.
		/// </summary>
		/// <param name="other">The other.</param>
		/// <returns></returns>
		public bool Equals(BusRoute other)
		{
			return other == null ? false : this.Id == other.Id;
		}

		/// <summary>
		/// Returns a hash code for this instance.
		/// </summary>
		/// <returns>
		/// A hash code for this instance, suitable for use in hashing algorithms and data structures like a hash table. 
		/// </returns>
		public override int GetHashCode()
		{
			return this.Id.GetHashCode();
		}

		/// <summary>
		/// Returns a <see cref="System.String"/> that represents this instance.
		/// </summary>
		/// <returns>
		/// A <see cref="System.String"/> that represents this instance.
		/// </returns>
		public override string ToString()
		{
			return this.ShortName;
		}
	}
}