﻿
using System;
using System.Collections.Generic;

namespace MsdnMag.ObaLib
{
	/// <summary>
	/// Contains data to represent a bus stop.
	/// </summary>
	public class BusStop : IEquatable<BusStop>
	{
		/// <summary>
		/// Gets the bus stop's id.
		/// </summary>
		/// <value>The id.</value>
		public string Id { get; private set; }

		/// <summary>
		/// Gets the bus stop's longitude.
		/// </summary>
		/// <value>The longitude.</value>
		public double Longitude { get; private set; }

		/// <summary>
		/// Gets the bus stop's latitude.
		/// </summary>
		/// <value>The latitude.</value>
		public double Latitude { get; set; }

		/// <summary>
		/// Gets the bus stop's direction.
		/// </summary>
		/// <value>The direction.</value>
		public string Direction { get; private set; }

		/// <summary>
		/// Gets the bus stop's display name.
		/// </summary>
		/// <value>The name.</value>
		public string Name { get; private set; }

		/// <summary>
		/// Gets the collection of bus routes which serve this bus stop
		/// </summary>
		/// <value>The bus routes.</value>
		public ICollection<BusRoute> BusRoutes { get; private set; }

		/// <summary>
		/// Initializes a new instance of the <see cref="BusStop"/> class.
		/// </summary>
		/// <param name="id">The id.</param>
		/// <param name="name">The name.</param>
		/// <param name="latitude">The latitude.</param>
		/// <param name="longitude">The longitude.</param>
		/// <param name="direction">The direction.</param>
		/// <param name="routes">The routes.</param>
		public BusStop(
			string id,
			string name, 
			double latitude, 
			double longitude, 
			string direction, 
			ICollection<BusRoute> routes)
		{
			this.Id = id;
			this.Name = name;
			this.Direction = direction;
			this.Longitude = longitude;
			this.Latitude = latitude;
			this.BusRoutes = routes;
		}

		/// <summary>
		/// Returns a <see cref="System.String"/> that represents this instance.
		/// </summary>
		/// <returns>
		/// A <see cref="System.String"/> that represents this instance.
		/// </returns>
		public override string ToString()
		{
			return this.Name;
		}

		/// <summary>
		/// Returns a hash code for this instance.
		/// </summary>
		/// <returns>
		/// A hash code for this instance, suitable for use in hashing algorithms and data structures like a hash table. 
		/// </returns>
		public override int GetHashCode()
		{
			return Id.GetHashCode();
		}

		/// <summary>
		/// Equalses the specified other.
		/// </summary>
		/// <param name="other">The other.</param>
		/// <returns></returns>
		public bool Equals(BusStop other)
		{
			return (this.Id == other.Id);
		}
	}
}